ProSHADE: src/bin/bin.cpp Source File

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

bin.cpp
Go to the documentation of this file.
1
26 //==================================================== DOxygen main page specifications
27
1370 //==================================================== ProSHADE
1371 #include "../proshade/ProSHADE.hpp"
1372
1373 //==================================================== Main
1374 int main ( int argc, char **argv )
1375 {
1376 //================================================ Create the settings object and parse the command line arguments
1377 ProSHADE_settings* settings = new ProSHADE_settings ( );
1378 settings->getCommandLineParams ( argc, argv );
1379
1380 //================================================ Execute
1381 ProSHADE_run *run = new ProSHADE_run ( settings );
1382
1383 //================================================ Release the settings object
1384 delete settings;
1385
1386 //================================================ Release the executive object
1387 delete run;
1388
1389 //================================================ DONE
1390 return ( EXIT_SUCCESS );
1391 }
ProSHADE_run
This class provides the access point to the library.
Definition: ProSHADE.hpp:39
ProSHADE_settings
This class stores all the settings and is passed to the executive classes instead of a multitude of p...
Definition: ProSHADE_settings.hpp:89
ProSHADE_settings::getCommandLineParams
void getCommandLineParams(int argc, char **argv)
This function parses the command line arguments into the settings object.
Definition: ProSHADE.cpp:1583